import { Pause, PlayArrow } from "@mui/icons-material";
import { IconButton, LinearProgress } from "@mui/material";

const UserVoiceCard = ({
  item,
  togglePlay,
  progress,
  buffered,
  buttonStatus,
  duration,
  currentTime,
}) => {
  const formatTime = (timeInSeconds) => {
    const minutes = Math.floor(timeInSeconds / 60);
    const seconds = Math.floor(timeInSeconds % 60)
      .toString()
      .padStart(2, "0");
    return `${minutes}:${seconds}`;
  };

  return (
    <div className="w-full h-full max-w-[294px] max-h-[108px] rounded-2xl border border-border-main flex flex-col gap-4 bg-background-main px-4 py-3 ">
      {/* user position  */}
      <div className="w-full h-8  flex justify-between">
        <div className="flex items-center gap-2">
          <div className="w-8 h-8 rounded-full bg-background-tertiary flex items-center justify-center ">
            <p className="font-bold text-primary-main">ح</p>
          </div>
          <p className="font-bold">{item.user}</p>
        </div>
        <div className="flex items-center">
          <p className="text-text-second text-xs">{item.date}</p>
        </div>
      </div>

      {/* player position  */}
      <div className="w-full h-8  flex gap-1 ">
        <div className="flex flex-1 h-full flex-col justify-between">
          <LinearProgress
            className="rotate-180"
            color="secondary"
            variant="buffer"
            value={progress}
            sx={{ borderRadius: "14px", width: "100%" }}
            valueBuffer={buffered}
          />
          <div className="w-full flex justify-end">
            <span className="text-text-second">
              {" "}
              {formatTime(duration)} / {formatTime(currentTime)}
            </span>
          </div>
        </div>
        <IconButton className="w-8 h-8 bg-accent-main" onClick={togglePlay}>
          {buttonStatus === "Play" ? (
            <PlayArrow sx={{ color: "#ffffff" }} />
          ) : (
            <Pause sx={{ color: "#ffffff" }} />
          )}
        </IconButton>
      </div>
    </div>
  );
};

export default UserVoiceCard;
